@@ -88,7 +88,7 @@ class PayerType(Enum):
 
 class PaymentDataSplit(BaseModel):
     code: str
-    amount: condecimal(ge=Decimal('0'), max_digits=12, decimal_places=2) | None = None
+    amount: Optional[condecimal(ge=Decimal('0'), max_digits=12, decimal_places=2)] = None
     meta: dict
 
     @validator('amount', pre=True)
@@ -143,7 +143,7 @@ class PaymentData(BaseModel):
     transaction_id: Optional[str]
     paid_at: Optional[datetime.datetime]
     expire_at: Optional[datetime.datetime]
-    amount: Optional[condecimal(ge=Decimal('0'), max_digits=12, decimal_places=2)] | None = None
+    amount: Optional[condecimal(ge=Decimal('0'), max_digits=12, decimal_places=2)] = None
     currency: CurrencyType
     type: Optional[PaymentType]
     notice_code: Optional[str]
