@@ -446,3 +446,61 @@ class PaymentTestCase(TestCase):
         )
         self.assertIsNone(pd.amount)
         self.assertIsNone(pd.amount_cents)
+
+    def test_split_amount_none_allowed_and_cents_zero(self):
+        s = PaymentDataSplit(code='Z', amount=None, meta={})
+        self.assertIsNone(s.amount)
+        self.assertEqual(s.amount_cents, 0)
+
+    def test_split_amount_empty_string_becomes_none(self):
+        s = PaymentDataSplit(code='A', amount='', meta={})
+        self.assertIsNone(s.amount)
+        self.assertEqual(s.amount_cents, 0)
+
+    def test_split_amount_negative_rejected(self):
+        with self.assertRaises(ValidationError) as ctx:
+            PaymentDataSplit(code='NEG', amount='-0.01', meta={})
+        self.assertIn('greater than or equal to 0', str(ctx.exception))
+
+    def test_split_rounding_half_up_various(self):
+        # Evito 1.005 che già testi altrove
+        s1 = PaymentDataSplit(code='R1', amount='0.004', meta={})
+        self.assertEqual(s1.amount, Decimal('0.00'))
+        self.assertEqual(s1.amount_cents, 0)
+
+        s2 = PaymentDataSplit(code='R2', amount='0.005', meta={})
+        self.assertEqual(s2.amount, Decimal('0.01'))
+        self.assertEqual(s2.amount_cents, 1)
+
+        s3 = PaymentDataSplit(code='R3', amount=1.239, meta={})
+        self.assertEqual(s3.amount, Decimal('1.24'))
+        self.assertEqual(s3.amount_cents, 124)
+
+    def test_split_meta_passthrough(self):
+        s = PaymentDataSplit(code='META', amount='2.50', meta={'k': 1})
+        self.assertEqual(s.meta, {'k': 1})
+
+    def test_split_amount_two_decimals_and_cents(self):
+        s = PaymentDataSplit(code='DEC', amount='123456.789', meta={})
+        self.assertEqual(s.amount, Decimal('123456.79'))
+        self.assertEqual(s.amount_cents, 12345679)
+
+    def test_split_amount_max_digits_enforced(self):
+        # max_digits=12, decimal_places=2 → più di 10 cifre intere + 2 decimali deve fallire
+        # Esempio: 123456789012.34 (12 cifre intere + 2 decimali = 14) → ValidationError
+        with self.assertRaises(ValidationError):
+            PaymentDataSplit(code='BIG', amount='123456789012.34', meta={})
+
+        # Limite valido vicino al bordo: 9999999999.99 (10 cifre intere + 2 decimali = 12) → OK
+        s_ok = PaymentDataSplit(code='OK', amount='9999999999.99', meta={})
+        self.assertEqual(s_ok.amount, Decimal('9999999999.99'))
+        self.assertEqual(s_ok.amount_cents, 999999999999)
+
+    def test_json_serialization_uses_paymentencoder_and_outputs_number(self):
+        s = PaymentDataSplit(code='SER', amount='0.01', meta={'x': True})
+        payload = json.loads(s.json())  # usa il tuo PaymentEncoder
+        # amount dev’essere numerico (non stringa) e 0.01
+        self.assertIsInstance(payload['amount'], (int, float))
+        self.assertEqual(payload['amount'], 0.01)
+        self.assertEqual(payload['code'], 'SER')
+        self.assertEqual(payload['meta'], {'x': True})
\ No newline at end of file
